==> qcad-3.15.5.3.tgz: lib/qcad/scripts/File/BitmapExport/ts/BitmapExport_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>BitmapExport</name>
    <message>
        <location filename="../BitmapExport.js" line="+105"/>
        <source>Files</source>
        <translatorcomment>--exact match--
--file: Image_pt.ts--
Todos os Arquivos de imagem (%1)
Todos os Ficheiros (*.*)</translatorcomment>
        <translation>Arquivos</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Export as Bitmap</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Exporte como Bitmap</translation>
    </message>
    <message>
        <location line="-61"/>
        <source>Error while generating Bitmap file &apos;%1&apos;: %2</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Erro ao gerar o arquivo Bitmap &apos;%1&apos;: %2</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Bitmap file has been exported to &apos;%1&apos;</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>O arquivo Bitmap foi exportado para &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../BitmapExportInit.js" line="+2"/>
        <source>Bit&amp;map Export...</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>&amp;Exporte como Bitmap...</translation>
    </message>
    <message>
        <location filename="../BitmapExportDialog.ui" line="+14"/>
        <source>Bitmap Export</source>
        <translatorcomment>--google--
Exporte como Bitmap...
Cor e transparência do fundo da página (também usada para exportar bitmaps</translatorcomment>
        <translation>Exporte como Bitmap</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Size</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Tamanho de Bitmap
Tamanho da seta:</translatorcomment>
        <translation>Tamanho</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Width:</source>
        <translatorcomment>--exact match--
--file: pt.po--
Largura:
&amp;Largura do Papel:</translatorcomment>
        <translation>Largura:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Height:</source>
        <translatorcomment>--exact match--
--file: pt.po--
Altura:
&amp;Altura do Papel:</translatorcomment>
        <translation>Altura:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Pixels per drawing unit:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Pixels por unidade de desenho:</translation>
    </message>
    <message>
        <location line="+72"/>
        <source>Margin:</source>
        <translation>Margem:</translation>
    </message>
    <message>
        <location line="+64"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Background</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Fundo
Pano de Fundo:
Pano de Fundo do Desenho:</translatorcomment>
        <translation>Pano de Fundo</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>White</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Branco / Preto
Branco / preto
Branco</translatorcomment>
        <translation>Branco</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Black</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Branco / Preto
Branco / preto
Preto</translatorcomment>
        <translation>Preto</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/File/BitmapExport/ts/BitmapExport_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>BitmapExport</name>
    <message>
        <location filename="../BitmapExport.js" line="+119"/>
        <source>Files</source>
        <translatorcomment>--exact match--
--file: Image_pt.ts--
Todos os Arquivos de imagem (%1)
Todos os Ficheiros (*.*)</translatorcomment>
        <translation>Arquivos</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Export as Bitmap</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Exporte como Bitmap</translation>
    </message>
    <message>
        <location line="-51"/>
        <source>Error while generating Bitmap file &apos;%1&apos;: %2</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Erro ao gerar o arquivo Bitmap &apos;%1&apos;: %2</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Bitmap file has been exported to &apos;%1&apos;</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>O arquivo Bitmap foi exportado para &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../BitmapExportInit.js" line="+2"/>
        <source>Bit&amp;map Export...</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>&amp;Exporte como Bitmap...</translation>
    </message>
    <message>
        <location filename="../BitmapExportDialog.ui" line="+14"/>
        <source>Bitmap Export</source>
        <translatorcomment>--google--
Exporte como Bitmap...
Cor e transparência do fundo da página (também usada para exportar bitmaps</translatorcomment>
        <translation>Exporte como Bitmap</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Size</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Tamanho de Bitmap
Tamanho da seta:</translatorcomment>
        <translation>Tamanho</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Width:</source>
        <translatorcomment>--exact match--
--file: pt.po--
Largura:
&amp;Largura do Papel:</translatorcomment>
        <translation>Largura:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Height:</source>
        <translatorcomment>--exact match--
--file: pt.po--
Altura:
&amp;Altura do Papel:</translatorcomment>
        <translation>Altura:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Pixels per drawing unit:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Pixels por unidade de desenho:</translation>
    </message>
    <message>
        <location line="+72"/>
        <source>Export bounding box of selection</source>
        <translation>Exporte a área retangular em torno da seleção</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Transparent</source>
        <translation>Transparente</translation>
    </message>
    <message>
        <location line="+10"/>
        <location line="+23"/>
        <source>Color</source>
        <translation>Cor</translation>
    </message>
    <message>
        <location line="-17"/>
        <source>Monochrome</source>
        <translation>Monocromático</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Grayscale</source>
        <translation>Escala de cinzas</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Anti-aliasing</source>
        <translation>Suavização</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Use anti-aliasing</source>
        <translation>Suavização</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Margin</source>
        <translation>Margem</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Margin:</source>
        <translation>Margem:</translation>
    </message>
    <message>
        <location line="+62"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Add extra margin to compensate for line weight</source>
        <translation>Adicione uma margem extra para compensar o peso da linha</translation>
    </message>
    <message>
        <location line="-170"/>
        <source>Background</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Fundo
Pano de Fundo:
Pano de Fundo do Desenho:</translatorcomment>
        <translation>Pano de Fundo</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>White</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Branco / Preto
Branco / preto
Branco</translatorcomment>
        <translation>Branco</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Black</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Branco / Preto
Branco / preto
Preto</translatorcomment>
        <translation>Preto</translation>
    </message>
</context>
<context>
    <name>BitmapExportWorker</name>
    <message>
        <location filename="../BitmapExportWorker.js" line="+106"/>
        <source>Invalid image size (width x height must be less than %1)</source>
        <translation>Tamanho de imagem inválido (largura x altura deve ser menor que %1)</translation>
    </message>
</context>
</TS>
